/*
 * Copyright 2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.instrumentation.api.annotations;

import org.gradle.internal.instrumentation.api.annotations.ReplacesEagerProperty.DefaultValue;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

@Retention(RetentionPolicy.CLASS)
@Target({ElementType.ANNOTATION_TYPE})
public @interface ReplacedAccessor {

    enum AccessorType {
        GETTER,
        SETTER
    }

    AccessorType value();

    /**
     * The name of the accessor, e.g. `getDestinationDir` or `setDestinationDir`
     */
    String name();

    /**
     * See {@link ReplacesEagerProperty#originalType()}
     */
    Class<?> originalType() default DefaultValue.class;

    /**
     * See {@link ReplacesEagerProperty#fluentSetter()}
     */
    boolean fluentSetter() default false;
}
