/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.launcher.daemon.server

import org.gradle.internal.event.ListenerManager
import org.gradle.launcher.daemon.server.expiry.DaemonExpirationListener
import org.gradle.launcher.daemon.server.expiry.DaemonExpirationStrategy
import spock.lang.Specification

class DaemonTest extends Specification {
    def "throwables are not propagated out of the run method of the expiration check"() {
        given:
        def check = new Daemon.DaemonExpirationPeriodicCheck(
            Mock(DaemonExpirationStrategy),
            Stub(ListenerManager) {
                getBroadcaster(DaemonExpirationListener) >> Mock(DaemonExpirationListener)
            }
        )

        when:
        check.run()

        then:
        1 * _ >> { throw throwable }
        noExceptionThrown()

        where:
        throwable              | _
        new Exception()        | _
        new RuntimeException() | _
        new Error()            | _
    }
}
